pub enum ApiKeyCurve {
Unspecified = 0,
P256 = 2,
Secp256k1 = 3,
Ed25519 = 4,
}Expand description
Cryptographic Curve used to generate a given API key
Variants
Implementations
Sourceimpl ApiKeyCurve
impl ApiKeyCurve
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.