pub enum Curve {
Unspecified = 0,
Secp256k1 = 1,
Ed25519 = 2,
P256 = 3,
}Expand description
Cryptographic Curve used to generate a given Private Key.
Variants
Unspecified = 0
Secp256k1 = 1
Curve SECP256K1 as defined in https://www.secg.org/sec2-v2.pdf
Ed25519 = 2
Curve ED25519 as defined in https://www.rfc-editor.org/rfc/rfc8032
P256 = 3
Curve NIST P-256 (secp256r1) as defined in https://csrc.nist.gov/csrc/media/events/workshop-on-elliptic-curve-cryptography-standards/documents/papers/session6-adalier-mehmet.pdf
Implementations
Sourceimpl Curve
impl Curve
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.