pub enum FiatOnRampPaymentMethod {
Show 14 variants
Unspecified = 0,
CreditDebitCard = 1,
ApplePay = 2,
GbpBankTransfer = 3,
GbpOpenBankingPayment = 4,
GooglePay = 5,
SepaBankTransfer = 6,
PixInstantPayment = 7,
Paypal = 8,
Venmo = 9,
MoonpayBalance = 10,
CryptoAccount = 11,
FiatWallet = 12,
AchBankAccount = 13,
}Variants
Unspecified = 0
Unspecified
CreditDebitCard = 1
Shared methods (supported by both MoonPay and Coinbase)
MoonPay: CREDIT_DEBIT_CARD, Coinbase: CARD
ApplePay = 2
MoonPay: APPLE_PAY, Coinbase: APPLE_PAY
GbpBankTransfer = 3
MoonPay-specific methods
MoonPay: GBP_BANK_TRANSFER
GbpOpenBankingPayment = 4
MoonPay: GBP_OPEN_BANKING_PAYMENT
GooglePay = 5
MoonPay: GOOGLE_PAY
SepaBankTransfer = 6
MoonPay: SEPA_BANK_TRANSFER
PixInstantPayment = 7
MoonPay: PIX_INSTANT_PAYMENT
Paypal = 8
MoonPay: PAYPAL
Venmo = 9
MoonPay: VENMO
MoonpayBalance = 10
MoonPay: MOONPAY_BALANCE
CryptoAccount = 11
Coinbase-specific methods
Coinbase: CRYPTO_ACCOUNT
FiatWallet = 12
Coinbase: FIAT_WALLET
AchBankAccount = 13
Coinbase: ACH_BANK_ACCOUNT
Implementations
Sourceimpl FiatOnRampPaymentMethod
impl FiatOnRampPaymentMethod
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.